@@ -11,9 +11,7 @@ def dal_check(app_configs, **kwargs):
         return []
 
     errors = []
-    missing_apps = {'dal', 'dal_select2'} - set(settings.INSTALLED_APPS)
+    missing_apps = {"dal", "dal_select2"} - set(settings.INSTALLED_APPS)
     for missing_app in missing_apps:
-        errors.append(
-            Error('{} needs to be in INSTALLED_APPS'.format(missing_app))
-        )
+        errors.append(Error("{} needs to be in INSTALLED_APPS".format(missing_app)))
     return errors
