@@ -11,5 +11,6 @@ except ImportError:
 HAS_TASK_MERGE = False
 if HAS_AUTOCOMPLETE:
     import dal.autocomplete
-    if getattr(dal.autocomplete, 'Select2QuerySetView', None) is not None:
+
+    if getattr(dal.autocomplete, "Select2QuerySetView", None) is not None:
         HAS_TASK_MERGE = True
